Learn R Programming

Rmixmod (version 2.1.1)

titanic: Qualitative data: Survival of passengers on the Titanic

Description

For each person on board the fatal maiden voyage of the ocean liner Titanic, this dataset records: sex, age [adult/child], economic status [first/second/third class, or crew] and whether or not that person survived. Values are aligned and delimited by blanks. There are no missing values.

Arguments

Format

A data frame with 2201 observations on the following 4 variables.

Class

0 = crew, 1 = first, 2 = second, 3 = third, which denote the economic status of the subject

Age

1 = adult, 0 = child, which denote if the subject is an adult or a child

Sex

1 = male, 0 = female, which denote the sex of the subject

Survived

1 = yes, 0 = no, which denote if the subject lived through the fatal maiden voyage of the ocean liner Titanic

Examples

Run this code
# NOT RUN {
data(titanic)
# }

Run the code above in your browser using DataLab